@@ -24,8 +24,11 @@ author:
 options:
   # General module options
     state:
-        description: Whether the snapshot should exist or not.
-        choices: ['present', 'absent']
+        description:
+          - Whether the snapshot should exist or not.
+          - C(started) and C(stopped) can only be used with aurora clusters
+          - Support for C(started) and C(stopped) was added in release 6.3.0.
+        choices: ['present', 'absent', 'started', 'stopped']
         default: 'present'
         type: str
     creation_source:
@@ -302,6 +305,13 @@ options:
         aliases:
           - maintenance_window
         type: str
+    remove_from_global_db:
+        description:
+          - If set to C(true), the cluster will be removed from global DB.
+          - Parameters I(global_cluster_identifier), I(db_cluster_identifier) must be specified when I(remove_from_global_db=true).
+        type: bool
+        required: false
+        version_added: 6.5.0
     replication_source_identifier:
         description:
           - The Amazon Resource Name (ARN) of the source DB instance or DB cluster if this DB cluster is created as a Read Replica.
@@ -430,7 +440,7 @@ EXAMPLES = r"""
     password: "{{ password }}"
     username: "{{ username }}"
     cluster_id: "{{ cluster_id }}"
-    skip_final_snapshot: True
+    skip_final_snapshot: true
     tags:
       Name: "cluster-{{ resource_prefix }}"
       Created_By: "Ansible_rds_cluster_integration_test"
@@ -460,6 +470,42 @@ EXAMPLES = r"""
     engine: aurora-postgresql
     state: present
     db_instance_class: 'db.t3.medium'
+
+- name: Remove a cluster from global DB (do not delete)
+  amazon.aws.rds_cluster:
+    db_cluster_identifier: '{{ cluster_id }}'
+    global_cluster_identifier: '{{ global_cluster_id }}'
+    remove_from_global_db: true
+
+- name: Remove a cluster from global DB and Delete without creating a final snapshot
+  amazon.aws.rds_cluster:
+    engine: aurora
+    password: "{{ password }}"
+    username: "{{ username }}"
+    cluster_id: "{{ cluster_id }}"
+    skip_final_snapshot: true
+    remove_from_global_db: true
+    wait: true
+    state: absent
+
+- name: Update cluster port and WAIT for remove secondary DB cluster from global DB to complete
+  amazon.aws.rds_cluster:
+    db_cluster_identifier: "{{ secondary_cluster_name }}"
+    global_cluster_identifier: "{{ global_cluster_name }}"
+    remove_from_global_db: true
+    state: present
+    port: 3389
+    region: "{{ secondary_cluster_region }}"
+
+- name: Update cluster port and DO NOT WAIT for remove secondary DB cluster from global DB to complete
+  amazon.aws.rds_cluster:
+    db_cluster_identifier: "{{ secondary_cluster_name }}"
+    global_cluster_identifier: "{{ global_cluster_name }}"
+    remove_from_global_db: true
+    state: present
+    port: 3389
+    region: "{{ secondary_cluster_region }}"
+    wait: false
 """
 
 RETURN = r"""
@@ -689,7 +735,6 @@ vpc_security_groups:
       sample: sg-12345678
 """
 
-
 try:
     import botocore
 except ImportError:
@@ -697,15 +742,15 @@ except ImportError:
 
 from ansible.module_utils.common.dict_transformations import camel_dict_to_snake_dict
 
-from ansible_collections.amazon.aws.plugins.module_utils.modules import AnsibleAWSModule
 from ansible_collections.amazon.aws.plugins.module_utils.botocore import is_boto3_error_code
+from ansible_collections.amazon.aws.plugins.module_utils.modules import AnsibleAWSModule
+from ansible_collections.amazon.aws.plugins.module_utils.rds import arg_spec_to_rds_params
+from ansible_collections.amazon.aws.plugins.module_utils.rds import call_method
+from ansible_collections.amazon.aws.plugins.module_utils.rds import ensure_tags
+from ansible_collections.amazon.aws.plugins.module_utils.rds import get_tags
+from ansible_collections.amazon.aws.plugins.module_utils.rds import wait_for_cluster_status
 from ansible_collections.amazon.aws.plugins.module_utils.retries import AWSRetry
 from ansible_collections.amazon.aws.plugins.module_utils.tagging import ansible_dict_to_boto3_tag_list
-from ansible_collections.amazon.aws.plugins.module_utils.rds import wait_for_cluster_status
-from ansible_collections.amazon.aws.plugins.module_utils.rds import arg_spec_to_rds_params
-from ansible_collections.amazon.aws.plugins.module_utils.rds import get_tags
-from ansible_collections.amazon.aws.plugins.module_utils.rds import ensure_tags
-from ansible_collections.amazon.aws.plugins.module_utils.rds import call_method
 
 
 @AWSRetry.jittered_backoff(retries=10)
@@ -770,6 +815,12 @@ def get_create_options(params_dict):
         "Domain",
         "DomainIAMRoleName",
         "EnableGlobalWriteForwarding",
+        "GlobalClusterIdentifier",
+        "AllocatedStorage",
+        "DBClusterInstanceClass",
+        "StorageType",
+        "Iops",
+        "EngineMode",
     ]
 
     return dict((k, v) for k, v in params_dict.items() if k in options and v is not None)
@@ -799,6 +850,11 @@ def get_modify_options(params_dict, force_update_password):
         "EnableGlobalWriteForwarding",
         "Domain",
         "DomainIAMRoleName",
+        "AllocatedStorage",
+        "DBClusterInstanceClass",
+        "StorageType",
+        "Iops",
+        "EngineMode",
     ]
     modify_options = dict((k, v) for k, v in params_dict.items() if k in options and v is not None)
     if not force_update_password:
@@ -910,6 +966,14 @@ def get_rds_method_attribute_name(cluster):
         if cluster and cluster["Status"] not in ["deleting", "deleted"]:
             method_name = "delete_db_cluster"
             method_options_name = "get_delete_options"
+    elif state == "started":
+        if cluster and cluster["Status"] not in ["starting", "started", "available"]:
+            method_name = "start_db_cluster"
+            method_options_name = "get_modify_options"
+    elif state == "stopped":
+        if cluster and cluster["Status"] not in ["stopping", "stopped"]:
+            method_name = "stop_db_cluster"
+            method_options_name = "get_modify_options"
     else:
         if cluster:
             method_name = "modify_db_cluster"
@@ -1019,6 +1083,16 @@ def changing_cluster_options(modify_params, current_cluster):
         if apply_immediately is not None:
             changing_params["ApplyImmediately"] = apply_immediately
 
+    if module.params["state"] == "started":
+        if current_cluster["Engine"] in ["mysql", "postgres"]:
+            module.fail_json("Only aurora clusters can use the state started")
+        changing_params["DBClusterIdentifier"] = db_cluster_id
+
+    if module.params["state"] == "stopped":
+        if current_cluster["Engine"] in ["mysql", "postgres"]:
+            module.fail_json("Only aurora clusters can use the state stopped")
+        changing_params["DBClusterIdentifier"] = db_cluster_id
+
     return changing_params
 
 
@@ -1028,6 +1102,7 @@ def ensure_present(cluster, parameters, method_name, method_options_name):
     if not cluster:
         if parameters.get("Tags") is not None:
             parameters["Tags"] = ansible_dict_to_boto3_tag_list(parameters["Tags"])
+
         call_method(client, module, method_name, eval(method_options_name)(parameters))
         changed = True
     else:
@@ -1070,12 +1145,39 @@ def ensure_present(cluster, parameters, method_name, method_options_name):
     return changed
 
 
+def handle_remove_from_global_db(module, cluster):
+    global_cluster_id = module.params.get("global_cluster_identifier")
+    db_cluster_id = module.params.get("db_cluster_identifier")
+    db_cluster_arn = cluster["DBClusterArn"]
+
+    if module.check_mode:
+        return True
+
+    try:
+        client.remove_from_global_cluster(DbClusterIdentifier=db_cluster_arn, GlobalClusterIdentifier=global_cluster_id)
+    except (botocore.exceptions.BotoCoreError, botocore.exceptions.ClientError) as e:
+        module.fail_json_aws(
+            e, msg=f"Failed to remove cluster {db_cluster_id} from global DB cluster {global_cluster_id}."
+        )
+
+    # for replica cluster - wait for cluster to change status from 'available' to 'promoting'
+    # only replica/secondary clusters have "GlobalWriteForwardingStatus" field
+    if "GlobalWriteForwardingStatus" in cluster:
+        wait_for_cluster_status(client, module, db_cluster_id, "db_cluster_promoting")
+
+    # if wait=true, wait for db cluster remove from global db operation to complete
+    if module.params.get("wait"):
+        wait_for_cluster_status(client, module, db_cluster_id, "cluster_available")
+
+    return True
+
+
 def main():
     global module
     global client
 
     arg_spec = dict(
-        state=dict(choices=["present", "absent"], default="present"),
+        state=dict(choices=["present", "absent", "started", "stopped"], default="present"),
         creation_source=dict(type="str", choices=["snapshot", "s3", "cluster"]),
         force_update_password=dict(type="bool", default=False),
         promote=dict(type="bool", default=False),
@@ -1122,6 +1224,7 @@ def main():
         port=dict(type="int"),
         preferred_backup_window=dict(aliases=["backup_window"]),
         preferred_maintenance_window=dict(aliases=["maintenance_window"]),
+        remove_from_global_db=dict(type="bool"),
         replication_source_identifier=dict(aliases=["replication_src_id"]),
         restore_to_time=dict(),
         restore_type=dict(choices=["full-copy", "copy-on-write"]),
@@ -1158,6 +1261,7 @@ def main():
         required_if=[
             ["creation_source", "snapshot", ["snapshot_identifier", "engine"]],
             ["creation_source", "s3", required_by_s3_creation_source],
+            ["remove_from_global_db", True, ["global_cluster_identifier", "db_cluster_identifier"]],
         ],
         mutually_exclusive=[
             ["s3_bucket_name", "source_db_cluster_identifier", "snapshot_identifier"],
@@ -1174,7 +1278,6 @@ def main():
         module.fail_json_aws(e, msg="Failed to connect to AWS.")
 
     if module.params.get("engine") and module.params["engine"] in ("mysql", "postgres"):
-        module.require_botocore_at_least("1.23.44", reason="to use mysql and postgres engines")
         if module.params["state"] == "present":
             if not (
                 module.params.get("allocated_storage")
@@ -1213,13 +1316,17 @@ def main():
             msg="skip_final_snapshot is False but all of the following are missing: final_snapshot_identifier"
         )
 
-    parameters = arg_spec_to_rds_params(dict((k, module.params[k]) for k in module.params if k in parameter_options))
-
     changed = False
+
+    parameters = arg_spec_to_rds_params(dict((k, module.params[k]) for k in module.params if k in parameter_options))
     method_name, method_options_name = get_rds_method_attribute_name(cluster)
 
     if method_name:
         if method_name == "delete_db_cluster":
+            if cluster and module.params.get("remove_from_global_db"):
+                if cluster["Engine"] in ["aurora", "aurora-mysql", "aurora-postgresql"]:
+                    changed = handle_remove_from_global_db(module, cluster)
+
             call_method(client, module, method_name, eval(method_options_name)(parameters))
             changed = True
         else:
@@ -1230,6 +1337,12 @@ def main():
     else:
         cluster_id = module.params["db_cluster_identifier"]
 
+    if cluster_id and get_cluster(cluster_id) and module.params.get("remove_from_global_db"):
+        if cluster["Engine"] in ["aurora", "aurora-mysql", "aurora-postgresql"]:
+            if changed:
+                wait_for_cluster_status(client, module, cluster_id, "cluster_available")
+        changed |= handle_remove_from_global_db(module, cluster)
+
     result = camel_dict_to_snake_dict(get_cluster(cluster_id))
 
     if result:
